#!/bin/sh

prefix=/root/worker/containers/00001nq3cvq/tmp/build/80754af9/jemalloc_1619184787581/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_
exec_prefix=/root/worker/containers/00001nq3cvq/tmp/build/80754af9/jemalloc_1619184787581/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_
libdir=${exec_prefix}/lib

LD_PRELOAD=${libdir}/libjemalloc.so.2
export LD_PRELOAD
exec "$@"
